<?php
namespace Teknisa\PED\Modules\Pedidos\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;
use \Zeedhi\Framework\DataSource\DataSet;

class ger96700TipoFiscalizacaoProdutoFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }

    public function deleteTpFiscalizacao($row) {
        $nrorg = $row['NRORG'];
        $nrtpfiscalprod = $row['NRTPFISCALPROD'];
        
        $this->deleteNcmControlados($nrorg, $nrtpfiscalprod);
        $this->deleteProdSemAlvara($nrorg, $nrtpfiscalprod);
        $this->deleteAlvaraTpFiscal($nrorg, $nrtpfiscalprod);
    }
    
    public function deleteNcmControlados($nrorg, $nrtpfiscalprod) {
        
        $sql = "DELETE FROM NCMCONTROLADOS
                WHERE  NRORG = :NRORG AND
                NRTPFISCALPROD    = :P_NRTPFISCALPROD";

        $params = array(
            'NRORG'=>$nrorg,
            'P_NRTPFISCALPROD'=>$nrtpfiscalprod,
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }
    
    public function deleteProdSemAlvara($nrorg, $nrtpfiscalprod){
        $sql = "DELETE FROM PRODSEMALVARA
                WHERE  NRORG = :NRORG AND
                NRTPFISCALPROD    = :P_NRTPFISCALPROD";

        $params = array(
            'NRORG'=>$nrorg,
            'P_NRTPFISCALPROD'=>$nrtpfiscalprod,
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteAlvaraTpFiscal($nrorg, $nrtpfiscalprod){
        $sql = "DELETE FROM ALVARATPFISCAL
                WHERE  NRORG = :NRORG AND
                NRTPFISCALPROD    = :P_NRTPFISCALPROD";

        $params = array(
            'NRORG'=>$nrorg,
            'P_NRTPFISCALPROD'=>$nrtpfiscalprod,
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function cadastroAutomatico($rows){
        foreach ($rows as $row){
            $this->deleteClasFiscal($row['NRORG'], $row['SGUNIDPADR'], $row['CDCLASFISC'], $row['NRTPFISCALPROD']);
            
            $sql = "INSERT INTO NCMCONTROLADOS (NRTPFISCALPROD, CDCLASFISC, SGUNIDPADR, QTMENSAL, NRORG)
    				VALUES (:P_NRTPFISCALPROD, :P_CDCLASFISC, :P_SGUNIDPADR, :P_QTMENSAL, :P_NRORG)";
    
            $params = array(
                'P_NRTPFISCALPROD'=>$row['NRTPFISCALPROD'],
                'P_CDCLASFISC'=>$row['CDCLASFISC'],
                'P_SGUNIDPADR'=>$row['SGUNIDPADR'],
                'P_QTMENSAL'=>$row['QTMENSAL'],
                'P_NRORG'=>$row['NRORG'],
            );
            
            try{
                $std = $this->connection->prepare($sql);
                $std->execute($params);
            }catch (\Exception $e){
                $response->setError(new Error("". $e->getMessage(), 500));
            }
        }
    }
    
    public function buscaClasfiscal($row, $response){
        $sql = "SELECT * FROM CLASFISCAL 
                WHERE NRORG = :P_NRORG";

        $params = array(
            'P_NRORG'=>$row['NRORG'],
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $rows = $std->fetchAll();
        foreach ($rows as $clasfisc) {
            $this->deleteClasFiscal($row['NRORG'], $row['SGUNIDPADR'],  $clasfisc['CDCLASFISC'], $row['NRTPFISCALPROD']);
        }
        
        foreach ($rows as $clasfisc) {
            $this->insereClasfiscal($row['SGUNIDPADR'], $row['QTMENSAL'], $row['NRTPFISCALPROD'], $clasfisc, $response);
        }
    }
    
    public function insereClasfiscal($sgunidade, $qtmensal, $nrtpfiscalprod, $clasfisc, $response){
        $sql = "INSERT INTO NCMCONTROLADOS (NRTPFISCALPROD, CDCLASFISC, SGUNIDPADR, QTMENSAL, NRORG)
				VALUES (:P_NRTPFISCALPROD, :P_CDCLASFISC, :P_SGUNIDPADR, :P_QTMENSAL, :P_NRORG)";

        $params = array(
            'P_NRTPFISCALPROD'=>$nrtpfiscalprod,
            'P_CDCLASFISC'=>$clasfisc['CDCLASFISC'],
            'P_SGUNIDPADR'=>$sgunidade,
            'P_QTMENSAL'=>$qtmensal,
            'P_NRORG'=>$clasfisc['NRORG'],
        );
        
        try{
            $std = $this->connection->prepare($sql);
            $std->execute($params);
        }catch (\Exception $e){
            $response->setError(new Error("". $e->getMessage(), 500));
        }
    }
    
    public function deleteClasFiscal($nrorg, $sgunidpadr, $cdclasfisc, $nrtpfiscalprod){
        $sql = "DELETE FROM NCMCONTROLADOS 
                WHERE NRORG = :P_NRORG AND SGUNIDPADR = :P_SGUNIDPADR AND CDCLASFISC = :P_CDCLASFISC AND NRTPFISCALPROD = :P_NRTPFISCALPROD";

        $params = array(
            'P_NRORG'=>$nrorg,
            'P_SGUNIDPADR'=>$sgunidpadr,
            'P_CDCLASFISC'=>$cdclasfisc,
            'P_NRTPFISCALPROD'=>$nrtpfiscalprod,
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function newCode($response){
        $sql = "SELECT MAX(NRTPFISCALPROD) FROM TPFISCALPROD";

        $std = $this->connection->prepare($sql);
        $std->execute();
        $dataSet = new DataSet ('data',$std->fetchAll()[0]);
        $response->addDataSet($dataSet);
    }
    
    
}
?>

