<?php
namespace Teknisa\PED\Modules\Pedidos\Factories;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Pedidosexpedicao\Entities\Precobase;
use Teknisa\Model\Pedidosexpedicao\Entities\Promoprbase;
use Teknisa\Model\Pedidosexpedicao\Entities\Opcioprbase;
use Teknisa\Model\Pedidosexpedicao\Entities\Itemprebase;
use Teknisa\Model\Eventos\Entities\Prbaseconvidaore;

class ped02300PrecoBaseFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }

public function setValidadeIntervalo($CDPRECOBASE,$CDPRODUTO,$QTCONVINIPRB,$QTCONVFINPRB,$NRORG) {
        $sql = "SELECT PC.NRORG, PC.CDPRECOBASE, PC.DTINIVALIPB, PC.CDPRODUTO, PC.QTCONVINIPRB,
                    PC.QTCONVFINPRB, PC.VRPREBASECONV, PC.QTHRDURACAOPB FROM PRBASECONVIDAORE PC
                WHERE
                    CDPRECOBASE = :CDPRECOBASE AND NRORG = :NRORG AND CDPRODUTO = :CDPRODUTO
                AND
                    ((:QTINICIAL BETWEEN PC.QTCONVINIPRB AND PC.QTCONVFINPRB)
                OR
                    (:QTFINAL BETWEEN PC.QTCONVINIPRB AND PC.QTCONVFINPRB))";

        $params = array("CDPRECOBASE" => $CDPRECOBASE,
                        "NRORG" => $NRORG,
                        "CDPRODUTO" => $CDPRODUTO,
                        "QTINICIAL" => $QTCONVINIPRB,
                        "QTFINAL" => $QTCONVFINPRB );

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetchAll();
    }

    /**
     * Busca Preco Base
     * @param $nrorg
     * @param $cdprecobase
     * @return Precobase
     */
    public function buscaPrecobase($nrorg, $cdprecobase){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdprecobase'] = $cdprecobase;

        /** @var Precobase $precobase */
        $precobase = $this->entityManager->getRepository(Precobase::class)->findOneBy($params);

        return $precobase;
    }

    /**
     * Busca Promoção Preço Base
     * @param $nrorg
     * @param $cdprecobase
     * @param $cdproduto
     * @return Promoprbase
     */
    public function buscaPromoprbase($nrorg, $cdprecobase, $cdproduto){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdprecobase'] = $cdprecobase;
        $params['cdproduto']   = $cdproduto;

        /** @var Promoprbase $promoprbase */
        $promoprbase = $this->entityManager->getRepository(Promoprbase::class)->findBy($params);

        return $promoprbase;
    }

    /**
     * Busca Preço Opcional
     * @param $nrorg
     * @param $cdprecobase
     * @param $cdproduto
     * @return Opcioprbase
     */
    public function buscaOpcioprbase($nrorg, $cdprecobase, $cdproduto){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdprecobase'] = $cdprecobase;
        $params['cdproduto']   = $cdproduto;

        /** @var Opcioprbase $opcioprbase */
        $opcioprbase = $this->entityManager->getRepository(Opcioprbase::class)->findBy($params);

        return $opcioprbase;
    }

    /**
     * Busca Preço Opcional
     * @param $nrorg
     * @param $cdprecobase
     * @param $cdproduto
     * @param $cdfatpreco
     * @return Opcioprbase
     */
    public function buscaOpcioprbaseFator($nrorg, $cdprecobase, $cdproduto, $cdfatpreco){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdprecobase'] = $cdprecobase;
        $params['cdproduto']   = $cdproduto;
        $params['cdfatpreco']  = $cdfatpreco;

        /** @var Opcioprbase $opcioprbase */
        $opcioprbase = $this->entityManager->getRepository(Opcioprbase::class)->findOneBy($params);

        return $opcioprbase;
    }

    /**
     * Busca Convidado(s)
     * @param $nrorg
     * @param $cdprecobase
     * @param $cdproduto
     * @return Promoprbase
     */
    public function buscaPrbaseconvidaore($nrorg, $cdproduto, $cdprecobase){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdproduto']   = $cdproduto;
        $params['cdprecobase'] = $cdprecobase;

        /** @var Prbaseconvidaore $prbaseconvidaore */
        $prbaseconvidaore = $this->entityManager->getRepository(Prbaseconvidaore::class)->findBy($params);

        return $prbaseconvidaore;
    }

    /**
     * Busca Item(s)
     * @param $nrorg
     * @param $cdprecobase
     * @param $cdproduto
     * @return Itemprebase
     */
    public function buscaItemprebase($nrorg, $cdprecobase, $cdproduto){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdproduto']   = $cdproduto;
        $params['cdprecobase'] = $cdprecobase;

        /** @var Prbaseconvidaore $prbaseconvidaore */
        $itemprebase = $this->entityManager->getRepository(Itemprebase::class)->findOneBy($params);

        return $itemprebase;
    }

    /**
     * Busca Item(s)
     * @param $nrorg
     * @param $cdprecobase
     * @param $cdproduto
     * @return Itemprebase
     */
    public function buscaItemprebaseReajuste($nrorg, $cdprecobase, $cdproduto){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdproduto']   = $cdproduto;
        $params['cdprecobase'] = $cdprecobase;

        /** @var Prbaseconvidaore $prbaseconvidaore */
        $itemprebase = $this->entityManager->getRepository(Itemprebase::class)->findBy($params);

        return $itemprebase;
    }

    /**
     * Insere Item Preco Base
     * @param $nrorg        @param $dtfimvalipb
     * @param $cdprecobase  @param $vriteprebase
     * @param $cdproduto    @param $dthratzipb
     * @param $dtinivalipb  @param $cdoperatzipb
     * @return Itemprebase
     */
    public static function insereItemprebase(
        $nrorg, $cdprecobase, $cdproduto, $dtinivalipb, $dtfimvalipb,
        $vriteprebase, $dthratzipb, $cdoperatzipb
    ){
        /** @var Itemprebase $itemprebase */
        $itemprebase = New Itemprebase();
        $itemprebase->setNrorg($nrorg);
        $itemprebase->setCdprecobase($cdprecobase);
        $itemprebase->setCdproduto($cdproduto);
        $itemprebase->setDtinivalipb($dtinivalipb);
        $itemprebase->setDtfimvalipb($dtfimvalipb);
        $itemprebase->setVriteprebase($vriteprebase);
        $itemprebase->setDthratzipb($dthratzipb);
        $itemprebase->setCdoperatzipb($cdoperatzipb);

        return $itemprebase;
    }

    /**
     * Insere Promocao Preco Base
     * @param $nrorg        @param $iddiaspromo     @param $vrtotalpromo
     * @param $cdprecobase  @param $dtinipromo      @param $idstatuspromo
     * @param $cdproduto    @param $dtfinpromo
     * @param $dtinivalipb  @param $idtipopromo
     * @return Promoprbase  @param $vrperbasepromo
     */
    public static function inserePromoprbase(
        $nrorg, $cdprecobase, $cdproduto, $dtinivalipb,
        $iddiaspromo, $dtinipromo, $dtfinpromo, $idtipopromo,
        $vrperbasepromo, $vrtotalpromo, $idstatuspromo
    ){
        /** @var Promoprbase $promoprbase */
        $promoprbase = New Promoprbase();
        $promoprbase->setNrorg($nrorg);
        $promoprbase->setCdprecobase($cdprecobase);
        $promoprbase->setCdproduto($cdproduto);
        $promoprbase->setDtinivalipb($dtinivalipb);
        $promoprbase->setIddiaspromo($iddiaspromo);
        $promoprbase->setDtinipromo($dtinipromo);
        $promoprbase->setDtfinpromo($dtfinpromo);
        $promoprbase->setIdtipopromo($idtipopromo);
        $promoprbase->setVrperbasepromo($vrperbasepromo);
        $promoprbase->setVrtotalpromo($vrtotalpromo);
        $promoprbase->setIdstatuspromo($idstatuspromo);

        return $promoprbase;
    }

    /**
     * Insere Opcional Preco Base
     * @param $nrorg        @param $cdfatpreco
     * @param $cdprecobase  @param $vropcioprbase
     * @param $cdproduto    @param $nrseqopcioprbase
     * @return Opcioprbase
     */
    public static function insereOpcioprbase(
        $nrorg, $cdprecobase, $cdproduto, $cdfatpreco,
        $vropcioprbase, $nrseqopcioprbase, $dtinclusao
    ){
        /** @var Opcioprbase $opcioprbase */
        $opcioprbase = New Opcioprbase();
        $opcioprbase->setNrorg($nrorg);
        $opcioprbase->setCdprecobase($cdprecobase);
        $opcioprbase->setCdproduto($cdproduto);
        $opcioprbase->setCdfatpreco($cdfatpreco);
        $opcioprbase->setVropcioprbase($vropcioprbase);
        $opcioprbase->setNrseqopcioprbase($nrseqopcioprbase);
        $opcioprbase->setDtinclusao($dtinclusao);
        $opcioprbase->setDtultatu($dtinclusao);

        return $opcioprbase;
    }

    /**
     * Insere Convidado
     * @param $nrorg        @param $dtinivalipb     @param $vrprebaseconv
     * @param $cdprecobase  @param $qtconviniprb    @param $qthrduracaopb
     * @param $cdproduto    @param $qtconvfinprb
     * @return Prbaseconvidaore
     */
    public static function inserePrbaseconvidaore(
        $nrorg, $cdprecobase, $cdproduto,
        $dtinivalipb, $qtconviniprb, $qtconvfinprb,
        $vrprebaseconv, $qthrduracaopb
    ){

        /** @var Convidado $convidado */
        $convidado = New Prbaseconvidaore();
        $convidado->setNrorg($nrorg);
        $convidado->setCdprecobase($cdprecobase);
        $convidado->setCdproduto($cdproduto);
        $convidado->setDtinivalipb($dtinivalipb);
        $convidado->setQtconviniprb($qtconviniprb);
        $convidado->setQtconvfinprb($qtconvfinprb);
        $convidado->setVrprebaseconv($vrprebaseconv);
        $convidado->setQthrduracaopb($qthrduracaopb);

        return $convidado;
    }
    
    public function updateDescMaximo($row, $cdprecobase, $sgestadoAntigo, $cdprodutoAntigo) {
        $vrpemaxdespr = strval($row['VRPEMAXDESPR']);
        $nrorg = strval($row['NRORG']);
        $sql = "UPDATE ITDESPREBASE
                    SET CDPRODUTO = :CDPRODUTO, SGESTADO = :SGESTADO, CDPAIS = :CDPAIS, VRPEMAXDESPR = :VRPEMAXDESPR, NRORG = :NRORG
                  WHERE CDPRECOBASE = :CDPRECOBASE 
                    AND CDPRODUTO = :CDPRODUTOANTIGO
                    AND SGESTADO = :SGESTADOANTIGO";

        $params = array("CDPRODUTO" => $row['CDPRODUTO'],
                        "CDPAIS" => $row['CDPAIS'],
                        "SGESTADO" => $row['SGESTADO'],
                        "VRPEMAXDESPR" => $vrpemaxdespr,
                        "NRORG" => $nrorg,
                        "CDPRECOBASE" => $cdprecobase,
                        "CDPRODUTOANTIGO" => $cdprodutoAntigo, 
                        "SGESTADOANTIGO" => $sgestadoAntigo);

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}

?>