<?php
namespace Teknisa\PED\Modules\Pedidos\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\Libs\Util\Environment;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\NewCode;

class Ped03500TabelaMetaComissaoService{


	protected $environment;
	protected $newCode;
	protected $dataSourceManager;

    public function __construct(Environment $environment, NewCode $newCode, $dataSourceManager){
        $this->environment = $environment;
        $this->newCode = $newCode;
        $this->dataSourceManager = $dataSourceManager;
    }

    public function cadastroAutomaticoItem($produtos, $row) {
        $dataSourceNameToSave = 'itcomissao';
        $this->deletaComissaoExistente($produtos, $row);

        $rowAuditoria = $this->adicionaCamposAuditoria($row);
        unset($rowAuditoria['CDPRODUTOINI']);
        unset($rowAuditoria['CDPRODUTOFIN']);

        foreach ($produtos as $produto) {
            $rowInsere = array();
            $rowInsere[0] = $rowAuditoria;
            $rowInsere[0]['CDPRODUTO'] = $produto['CDPRODUTO'];
            $dataSet = new DataSet($dataSourceNameToSave, $rowInsere);

            try{
                $this->dataSourceManager->persist($dataSet);
            }
            catch(\Exception $e) {
                throw $e;
            }
        }

    }

    public function deletaComissaoExistente($produtos, $row) {
        $dataSource = 'itcomissao';
        $valores = array($row['VRINICVENDA'], $row['VRFINAVENDA']);
        foreach ($produtos as $produto) {
            $conditionsVInicial = array(
                array(
                 "value" => $row['CDFILIAL'],
    	        "operator" => "=",
    	        "columnName" => "CDFILIAL"
        	      ),
                array(
                    "value" => $row['CDCOMISSAO'],
        	        "operator" => "=",
        	        "columnName" => "CDCOMISSAO"
        	      ),
    	        array(
                    "value" => $produto['CDPRODUTO'],
        	        "operator" => "=",
        	        "columnName" => "CDPRODUTO"
        	     ),
        	     array(
                    "value" => $valores,
        	        "operator" => "BETWEEN",
        	        "columnName" => "VRINICVENDA"
        	     )
            );

            $filterCriteria = new FilterCriteria($dataSource, $conditionsVInicial);
            $result = $this->dataSourceManager->findBy($filterCriteria);

            try{
                $this->dataSourceManager->delete($result);
            }
            catch(\Exception $e) {
                throw $e;
            }

            $conditionsVFinal = array(
                array(
                    "value" => $row['CDFILIAL'],
        	        "operator" => "=",
        	        "columnName" => "CDFILIAL"
        	     ),
                array(
                    "value" => $row['CDCOMISSAO'],
        	        "operator" => "=",
        	        "columnName" => "CDCOMISSAO"
        	      ),
    	        array(
                    "value" => $produto['CDPRODUTO'],
        	        "operator" => "=",
        	        "columnName" => "CDPRODUTO"
        	     ),
        	     array(
                    "value" => $valores,
        	        "operator" => "BETWEEN",
        	        "columnName" => "VRFINAVENDA"
        	     )

            );

            $filterCriteria = new FilterCriteria($dataSource, $conditionsVFinal);
            $result = $this->dataSourceManager->findBy($filterCriteria);
            try{
                $this->dataSourceManager->delete($result);
            }
            catch(\Exception $e) {
                throw $e;
            }

            $conditionsBT = array(
                array(
                 "value" => $row['CDFILIAL'],
    	        "operator" => "=",
    	        "columnName" => "CDFILIAL"
        	      ),
                array(
                    "value" => $row['CDCOMISSAO'],
        	        "operator" => "=",
        	        "columnName" => "CDCOMISSAO"
        	      ),
    	        array(
                    "value" => $produto['CDPRODUTO'],
        	        "operator" => "=",
        	        "columnName" => "CDPRODUTO"
        	     ),
        	     array(
                    "value" => $row['VRINICVENDA'],
        	        "operator" => "<=",
        	        "columnName" => "VRINICVENDA"
        	     ),
        	     array(
                    "value" => $row['VRINICVENDA'],
        	        "operator" => ">=",
        	        "columnName" => "VRFINAVENDA"
        	     ),
        	     array(
                    "value" => $row['VRFINAVENDA'],
        	        "operator" => "<=",
        	        "columnName" => "VRINICVENDA"
        	     ),
        	     array(
                    "value" => $row['VRFINAVENDA'],
        	        "operator" => ">=",
        	        "columnName" => "VRFINAVENDA"
        	     )
            );

            $filterCriteria = new FilterCriteria($dataSource, $conditionsBT);
            $result = $this->dataSourceManager->findBy($filterCriteria);

            try{
                $this->dataSourceManager->delete($result);
            }
            catch(\Exception $e) {
                throw $e;
            }

        }
    }

    public function cadastroAutomaticoProduto($row) {
        $dataSource = 'prodmetavend';
        $produtos = $this->consultaProdutos($row);



        $rowAuditoria = $this->adicionaCamposAuditoria($row);
        unset($rowAuditoria['CDPRODUTOINI']);
        unset($rowAuditoria['CDPRODUTOFIN']);
        unset($rowAuditoria['CDARVPRODINI']);
        unset($rowAuditoria['CDARVPRODFIN']);

        $produtos = $this->removeProdutosRepetidos($produtos, $row);
        if($produtos) {
            foreach ($produtos as $produto) {
                $rowInsere = array();
                $rowInsere[0] = $rowAuditoria;
                $rowInsere[0]['CDPRODUTO'] = $produto['CDPRODUTO'];
                $dataSet = new DataSet($dataSource, $rowInsere);
                try{
                    $this->dataSourceManager->persist($dataSet);
                }
                catch(\Exception $e) {
                    throw $e;
                }
            }
        }


    }

    public function removeProdutosRepetidos($produtos, $row) {

        $dataSource = 'prodmetavend';
        $i = 0;
        foreach ($produtos as $produto) {
            $conditions = array(
    	        array(
        	        "value" => $row['CDMETAVENDA'],
        	        "operator" => "=",
        	        "columnName" => "CDMETAVENDA"
        	      ),
    	       array(
    	            "value" => $produto['CDPRODUTO'],
    	            "operator" => "=",
        	        "columnName" => "CDPRODUTO"
        	      )
            );
            $filterCriteria = new FilterCriteria($dataSource, $conditions);
            $result = $this->dataSourceManager->findBy($filterCriteria);
            if($result->getRows())  unset($produtos[$i]);

            $i++;
        }
        return $produtos;

    }

    public function consultaProdutos($row) {
        $dataSource = 'produto';
        $dataSourceNameToSave = 'itcomissao';

        $conditions = array(
	        array(
    	        "value" => $row['CDPRODUTOINI'],
    	        "operator" => ">=",
    	        "columnName" => "CDPRODUTO"
    	      ),
	       array(
	            "value" => $row['CDPRODUTOFIN'],
	            "operator" => "<=",
    	        "columnName" => "CDPRODUTO"
    	      )
        );

        $filterCriteria = new FilterCriteria($dataSource, $conditions);
        $result = $this->dataSourceManager->findBy($filterCriteria);
        $produtos = $result->getRows();
        return $produtos;
    }

    public function adicionaCamposAuditoria($row) {
        $nrorg = $this->environment->getNrorgTrab();
		$operador = $this->environment->getCdOperador();
		$currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
		$row['NRORG'] = $nrorg;
		$row['DTINCLUSAO'] = $currentTime;
		$row['DTULTATU'] = $currentTime;
		$row['CDOPERINCLUSAO'] = $operador;
		$row['CDOPERULTATU'] = $operador;
		$row['IDATIVO'] = 'S';
		$row['NRORGINCLUSAO'] = $nrorg;
		$row['NRORGULTATU'] = $nrorg;
		$row['__is_new'] = true;
		return $row;

    }
    
    public function geraNrSeq($__new_code_pk) {
        $nrseq = $this->newCode->getCodeByTableName($__new_code_pk, $this->environment->getNrOrgTrab(), 1, 4);
        return array($nrseq, $this->environment->getNrOrgTrab());
    }
    
}
